Package: linux-headers{{source_suffix}}{{localversion}}
Meta-Rules-Target: meta
Meta-Rules-Makeflags: INSTALLDOCS_LINK_DOC=linux-base{{source_suffix}}{{localversion}}
Build-Profiles: <!pkg.linux.nokernel !pkg.linux.nometa>
Depends:
 linux-base{{source_suffix}}{{localversion}} (= ${binary:Version}),
 linux-headers-{{abiname}}{{localversion}} (= ${binary:Version}),
 ${misc:Depends},
Provides:
{% if config.defs_flavour.is_default %}
 linux-headers-generic,
{% endif %}
Description: Linux for {{class}} (module development meta-package)
 This package depends on the architecture-specific header files for the latest
 Linux kernel {{flavour}} configuration.
